==> nextcloud-app-deck-1%3A1.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ar.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "لقد قمت بانشاء لوح جديد {board}",
    "{user} has created a new board {board}" : "{user} قام بانشاء لوح {board}",
    "You have deleted the board {board}" : "قمت بمسح اللوح {board}",
    "{user} has deleted the board {board}" : "{user} مَسحْ اللوح {board}",
    "You have restored the board {board}" : "لقد استعدت اللوح {board}",
    "{user} has restored the board {board}" : "{user} قام باسترجاع اللوح {board}",
    "You have shared the board {board} with {acl}" : "قمت بمشاركة اللوح {board} مع {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} قام بمشاركة اللوح {board} مع {acl}",
    "You have removed {acl} from the board {board}" : "قمت بازالة {acl} من اللوح {board}",
    "{user} has removed {acl} from the board {board}" : "{user} قام بازالة {acl} من اللوح {board}",
    "You have renamed the board {before} to {board}" : "قمت باعادة تسمية اللوح من {before} الى {board}",
    "{user} has renamed the board {before} to {board}" : "{user} قام باعادة تسمية اللوح من {before} الى {board}",
    "You have archived the board {board}" : "لقد ارشفت اللوح {board}",
    "{user} has archived the board {before}" : "{user} قام بأرشفة اللوح {before}",
    "You have unarchived the board {board}" : "قمت بالغاء ارشفة اللوح {board}",
    "{user} has unarchived the board {before}" : "{user} قام بالغاء ارشفة اللوح {before}",
    "Personal" : "شخصي",
    "No data was provided to create an attachment." : "لا بيانات تم تقديمها لانشاء مرفق",
    "Finished" : "إكتمل",
    "To review" : "لاعادة المراجعة",
    "Action needed" : "يحتاج الى اجراء",
    "Later" : "لاحقا",
    "copy" : "أنسخ",
    "To do" : "لفعله",
    "Doing" : "تحت العمل",
    "Done" : "أُنجز",
    "Example Task 3" : "مثال المهمة 3",
    "Example Task 2" : "مثال المهمة 2",
    "Example Task 1" : "مثال المهمة 1",
    "The file was uploaded" : "الملف تم رفعه",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The file was only partially uploaded" : "الملف قد رُفع جزءا منه فقط",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Could not write file to disk" : "لم يستطع كتابة ملف للقرص",
    "A PHP extension stopped the file upload" : "اضافة البي اچ بي PHP اوقفت رفع الملف",
    "Personal planning and team project organization" : "التخطيط الشخصي و تنظيم مشروع الفريق",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "دك (Deck) هو أداة تنظيم باسلوب كانبان (kanban) تهدف إلى التخطيط الشخصي وتنظيم المشروع للفرق مع نيكست كلاود (Nextcloud).\n- 📥 إضافة مهامك إلى البطاقات وترتيبها\n- 📄 كتابة ملاحظات إضافية  باستخدام مارك داون (markdown)\n- 🔖 تعيين تسميات لتنظيم أفضل\n- 👥 شارك مع فريقك أو أصدقائك أو عائلتك\n- 📎 إرفاق الملفات وتضمينها بالوصف المستخدم فيه مارك داون (markdown)\n- 💬 ناقش مع فريقك باستخدام التعليقات\n- ⚡ تتبع التغييرات في تيار النشاط\n- 🚀 اجعل مشروعك منظماً",
    "Create new board" : "انشاء لوح جديد",
    "new board" : "لوح جديد",
    "Select the board to link to a project" : "تحديد اللوح لربطه بمشروع",
    "Search by board title" : "بحث بواسطة عنوان اللوح",
    "Select board" : "حدد لوح",
    "Select the card to link to a project" : "حدد البطاقة لربطها بمشروع",
    "Select a board" : "حدد لوح",
    "Select a card" : "حدد بطاقة",
    "Link to card" : "اربط بطاقة",
    "Cancel" : "إلغاء",
    "File already exists" : "الملف موجود مسبقاً",
    "Do you want to overwrite it?" : "هل تريد تجاوزه؟",
    "Overwrite file" : "تجاوز ملف",
    "Keep existing file" : "ابقي الملف الموجود",
    "This board is read only" : "هذا اللوح بوضع القراءة فقط",
    "Drop your files to upload" : "افلت الملفات لرفعها",
    "Archived cards" : "البطاقات المؤرشفة",
    "Add new list" : "اضف قائمة جديدة",
    "List name" : "قامة اسماء",
    "Apply filter" : "تطبيق التصفية",
    "Filter by tag" : "تصفية بواسطة الوسم",
    "Filter by assigned user" : "تصفية بواسطة المستخدم الموكل اليه",
    "Filter by due date" : "تصفية بواسطة تأريخ الانجاز",
    "Overdue" : "تأخر",
    "Next 24 hours" : "ال 24 ساعة القادمة",
    "Next 7 days" : "ال 7 ايام القادمة",
    "Next 30 days" : "ال 30 يوم القادمة",
    "No due date" : "لا تأريخ انجاز",
    "Clear filter" : "ازل التصفية",
    "Show archived cards" : "اظهر البطاقات المؤرشفة",
    "Details" : "التفاصيل",
    "Loading board" : "اللوح يحمل..",
    "Board not found" : "اللوح غير موجود",
    "Sharing" : "المشاركة",
    "Tags" : "الوسوم",
    "Deleted items" : "العناصر الممسوحة",
    "Timeline" : "الجدول الزمني",
    "Deleted lists" : "القوائم المحذوفة",
    "Undo" : "تراجع",
    "Deleted cards" : "البطاقات المحذوفة",
    "Share board with a user, group or circle …" : "مشاركة اللوح مع مستخدم،مجموعة او دائرة ..",
    "Board owner" : "منشئ اللوح",
    "(Group)" : "(مجموعة)",
    "(Circle)" : "(دائرة)",
    "Can edit" : "يمكن تعديله",
    "Can share" : "يمكن مشاركته",
    "Can manage" : "يمكن ادارته",
    "Delete" : "حذف ",
    "Delete list" : "حذف القائمة",
    "Add card" : "إضافة بطاقة",
    "Add a new card" : "إضافة بطاقة جديدة",
    "Edit" : "تعديل",
    "Add a new tag" : "إضافة وسم جديد",
    "title and color value must be provided" : "العنوان و قيمة اللون يجب تقديمها ",
    "Title" : "العنوان",
    "Members" : "الاعضاء",
    "Add this attachment" : "إضافة هذا المرفق",
    "Delete Attachment" : "مسح المرفق",
    "Restore Attachment" : "استعادة المرفق",
    "Assign a tag to this card…" : "انسب وسم الى هذه البطاقة..",
    "Assign to users" : "انسب الى المتسخدمين",
    "Assign to users/groups/circles" : "انسب الى المستخدمين،المجموعات،الدوائر",
    "Assign a user to this card…" : "انسب مستخدم الى هذه البطاقة..",
    "Due date" : "تاريخ الانجاز",
    "Set a due date" : "تعيين تاريخ الانجاز",
    "Remove due date" : "ازالة تاريخ الانجاز",
    "Description" : "الوصف",
    "(Unsaved)" : "(غير محفوظ)",
    "(Saving…)" : "(يُحفظ..)",
    "Edit description" : "تعديل الوصف",
    "View description" : "إظهار الوصف",
    "Add Attachment" : "أضف ملحق",
    "Attachments" : "المرفقات",
    "Comments" : "تعليقات",
    "Choose attachment" : "اختيار مرفق",
    "Modified" : "عُدل",
    "Created" : "أُنشئ",
    "Upload attachment" : "رفع المرفقات",
    "No comments yet. Begin the discussion!" : "لا يوجد تعليقات بعد, ابدأ النقاش الآن!",
    "Save" : "حفظ",
    "The comment cannot be empty." : "التعليق لايمكن ان يكون فارغا.",
    "The comment cannot be longer than 1000 characters." : "التعليق لا يمكن ان يكون اطول من 1000 حرف.",
    "In reply to" : "يقوم بالرد على",
    "Reply" : "رد",
    "Update" : "تحديث",
    "(group)" : "(مجموعة)",
    "(circle)" : "(دائرة)",
    "seconds ago" : "ثوانٍ مضت",
    "Assign to me" : "ينسب لي",
    "Delete card" : "حذف البطاقة",
    "Move card" : "حرك البطاقة",
    "Card details" : "تفاصيل البطاقة",
    "Move card to another board" : "حرك البطاقة الى لوح اخر",
    "All boards" : "جميع الالواح",
    "Archived boards" : "الالواح المؤرشفة",
    "Shared with you" : "شورك معك",
    "Limit deck usage of groups" : "استخدام دك   Deck محدود للمجاميع",
    "New board title" : "عنوان لوح جديد",
    "Edit board" : "تعديل اللوح",
    "Board details" : "تفاصيل لوح",
    "An error occurred" : "طرأ هناك خطأ",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "هل انت متأكد تريد مسح اللوح {title}؟ هذا سوف يمسح جميع بيانات هذا اللوح.",
    "Delete the board?" : "مسح اللوح؟",
    "Link to a board" : "ربط بلوح",
    "Link to a card" : "ربط ببطاقة",
    "Something went wrong" : "شيئا ما خاطئ"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-app-deck-1%3A1.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ar.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "لقد قمت بانشاء لوح جديد {board}",
    "{user} has created a new board {board}" : "{user} قام بانشاء لوح {board}",
    "You have deleted the board {board}" : "قمت بمسح اللوح {board}",
    "{user} has deleted the board {board}" : "{user} مَسحْ اللوح {board}",
    "You have restored the board {board}" : "لقد استعدت اللوح {board}",
    "{user} has restored the board {board}" : "{user} قام باسترجاع اللوح {board}",
    "You have shared the board {board} with {acl}" : "قمت بمشاركة اللوح {board} مع {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} قام بمشاركة اللوح {board} مع {acl}",
    "You have removed {acl} from the board {board}" : "قمت بازالة {acl} من اللوح {board}",
    "{user} has removed {acl} from the board {board}" : "{user} قام بازالة {acl} من اللوح {board}",
    "You have renamed the board {before} to {board}" : "قمت باعادة تسمية اللوح من {before} الى {board}",
    "{user} has renamed the board {before} to {board}" : "{user} قام باعادة تسمية اللوح من {before} الى {board}",
    "You have archived the board {board}" : "لقد ارشفت اللوح {board}",
    "{user} has archived the board {before}" : "{user} قام بأرشفة اللوح {before}",
    "You have unarchived the board {board}" : "قمت بالغاء ارشفة اللوح {board}",
    "{user} has unarchived the board {before}" : "{user} قام بالغاء ارشفة اللوح {before}",
    "Personal" : "شخصي",
    "No data was provided to create an attachment." : "لا بيانات تم تقديمها لانشاء مرفق",
    "Finished" : "إكتمل",
    "To review" : "لاعادة المراجعة",
    "Action needed" : "يحتاج الى اجراء",
    "Later" : "لاحقا",
    "copy" : "أنسخ",
    "To do" : "لفعله",
    "Doing" : "تحت العمل",
    "Done" : "أُنجز",
    "Example Task 3" : "مثال المهمة 3",
    "Example Task 2" : "مثال المهمة 2",
    "Example Task 1" : "مثال المهمة 1",
    "The file was uploaded" : "الملف تم رفعه",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The file was only partially uploaded" : "الملف قد رُفع جزءا منه فقط",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Could not write file to disk" : "لم يستطع كتابة ملف للقرص",
    "A PHP extension stopped the file upload" : "اضافة البي اچ بي PHP اوقفت رفع الملف",
    "Personal planning and team project organization" : "التخطيط الشخصي و تنظيم مشروع الفريق",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "دك (Deck) هو أداة تنظيم باسلوب كانبان (kanban) تهدف إلى التخطيط الشخصي وتنظيم المشروع للفرق مع نيكست كلاود (Nextcloud).\n- 📥 إضافة مهامك إلى البطاقات وترتيبها\n- 📄 كتابة ملاحظات إضافية  باستخدام مارك داون (markdown)\n- 🔖 تعيين تسميات لتنظيم أفضل\n- 👥 شارك مع فريقك أو أصدقائك أو عائلتك\n- 📎 إرفاق الملفات وتضمينها بالوصف المستخدم فيه مارك داون (markdown)\n- 💬 ناقش مع فريقك باستخدام التعليقات\n- ⚡ تتبع التغييرات في تيار النشاط\n- 🚀 اجعل مشروعك منظماً",
    "Card details" : "تفاصيل البطاقة",
    "Select the board to link to a project" : "تحديد اللوح لربطه بمشروع",
    "Search by board title" : "بحث بواسطة عنوان اللوح",
    "Select board" : "حدد لوح",
    "Select the card to link to a project" : "حدد البطاقة لربطها بمشروع",
    "Select a board" : "حدد لوح",
    "Select a card" : "حدد بطاقة",
    "Link to card" : "اربط بطاقة",
    "Cancel" : "إلغاء",
    "File already exists" : "الملف موجود مسبقاً",
    "Do you want to overwrite it?" : "هل تريد تجاوزه؟",
    "Overwrite file" : "تجاوز ملف",
    "Keep existing file" : "ابقي الملف الموجود",
    "This board is read only" : "هذا اللوح بوضع القراءة فقط",
    "Drop your files to upload" : "افلت الملفات لرفعها",
    "Archived cards" : "البطاقات المؤرشفة",
    "List name" : "قامة اسماء",
    "Apply filter" : "تطبيق التصفية",
    "Filter by tag" : "تصفية بواسطة الوسم",
    "Filter by assigned user" : "تصفية بواسطة المستخدم الموكل اليه",
    "Filter by due date" : "تصفية بواسطة تأريخ الانجاز",
    "Overdue" : "تأخر",
    "Next 24 hours" : "ال 24 ساعة القادمة",
    "Next 7 days" : "ال 7 ايام القادمة",
    "Next 30 days" : "ال 30 يوم القادمة",
    "No due date" : "لا تأريخ انجاز",
    "Clear filter" : "ازل التصفية",
    "Show archived cards" : "اظهر البطاقات المؤرشفة",
    "Details" : "التفاصيل",
    "Loading board" : "اللوح يحمل..",
    "Board not found" : "اللوح غير موجود",
    "Sharing" : "المشاركة",
    "Tags" : "الوسوم",
    "Deleted items" : "العناصر الممسوحة",
    "Timeline" : "الجدول الزمني",
    "Deleted lists" : "القوائم المحذوفة",
    "Undo" : "تراجع",
    "Deleted cards" : "البطاقات المحذوفة",
    "Share board with a user, group or circle …" : "مشاركة اللوح مع مستخدم،مجموعة او دائرة ..",
    "Board owner" : "منشئ اللوح",
    "(Group)" : "(مجموعة)",
    "(Circle)" : "(دائرة)",
    "Can edit" : "يمكن تعديله",
    "Can share" : "يمكن مشاركته",
    "Can manage" : "يمكن ادارته",
    "Delete" : "حذف ",
    "Delete list" : "حذف القائمة",
    "Add card" : "إضافة بطاقة",
    "Add a new card" : "إضافة بطاقة جديدة",
    "Edit" : "تعديل",
    "Add a new tag" : "إضافة وسم جديد",
    "title and color value must be provided" : "العنوان و قيمة اللون يجب تقديمها ",
    "Title" : "العنوان",
    "Members" : "الاعضاء",
    "Upload attachment" : "رفع المرفقات",
    "Add this attachment" : "إضافة هذا المرفق",
    "Delete Attachment" : "مسح المرفق",
    "Restore Attachment" : "استعادة المرفق",
    "Assign a tag to this card…" : "انسب وسم الى هذه البطاقة..",
    "Assign to users" : "انسب الى المتسخدمين",
    "Assign to users/groups/circles" : "انسب الى المستخدمين،المجموعات،الدوائر",
    "Assign a user to this card…" : "انسب مستخدم الى هذه البطاقة..",
    "Due date" : "تاريخ الانجاز",
    "Set a due date" : "تعيين تاريخ الانجاز",
    "Remove due date" : "ازالة تاريخ الانجاز",
    "Description" : "الوصف",
    "(Unsaved)" : "(غير محفوظ)",
    "(Saving…)" : "(يُحفظ..)",
    "Edit description" : "تعديل الوصف",
    "View description" : "إظهار الوصف",
    "Add Attachment" : "أضف ملحق",
    "Attachments" : "المرفقات",
    "Comments" : "تعليقات",
    "Choose attachment" : "اختيار مرفق",
    "Modified" : "عُدل",
    "Created" : "أُنشئ",
    "No comments yet. Begin the discussion!" : "لا يوجد تعليقات بعد, ابدأ النقاش الآن!",
    "Save" : "حفظ",
    "The comment cannot be empty." : "التعليق لايمكن ان يكون فارغا.",
    "The comment cannot be longer than 1000 characters." : "التعليق لا يمكن ان يكون اطول من 1000 حرف.",
    "In reply to" : "يقوم بالرد على",
    "Reply" : "رد",
    "Update" : "تحديث",
    "(group)" : "(مجموعة)",
    "(circle)" : "(دائرة)",
    "Assign to me" : "ينسب لي",
    "Delete card" : "حذف البطاقة",
    "Move card" : "حرك البطاقة",
    "Move card to another board" : "حرك البطاقة الى لوح اخر",
    "seconds ago" : "ثوانٍ مضت",
    "All boards" : "جميع الالواح",
    "Archived boards" : "الالواح المؤرشفة",
    "Shared with you" : "شورك معك",
    "Limit deck usage of groups" : "استخدام دك   Deck محدود للمجاميع",
    "Edit board" : "تعديل اللوح",
    "Board details" : "تفاصيل لوح",
    "An error occurred" : "طرأ هناك خطأ",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "هل انت متأكد تريد مسح اللوح {title}؟ هذا سوف يمسح جميع بيانات هذا اللوح.",
    "Delete the board?" : "مسح اللوح؟",
    "Today" : "اليوم",
    "Tomorrow" : "غدا",
    "This week" : "هذا الأسبوع",
    "Link to a board" : "ربط بلوح",
    "Link to a card" : "ربط ببطاقة",
    "Something went wrong" : "شيئا ما خاطئ"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
